@@ -86,6 +86,9 @@ typedef struct {
     GtkWidget *widget_sensors;
 
     /* panel value display */
+    GtkWidget *panel_label_data;
+
+    /* optional label for plugin */
     GtkWidget *panel_label_text;
 
     /* update the tooltip */
@@ -220,10 +223,6 @@ typedef struct {
 }
 t_sensors_dialog;
 
-/*
- * Tooltips to display for any part of this plugin
- */
-static GtkTooltips *tooltips = NULL;
 
 
 #endif /* XFCE4_SENSORS_SENSORS_H */
